@@ -1,11 +1,12 @@
 mod ffi;
 use crate::ffi::{ CSource, CSink, CError };
+use std::os::raw::c_char;
 
 
 const API_VERSION: u8 = 1;
 const TEST_USER_SECRET: &[u8] = b"Testolope";
-static FORMAT_UID: &'static [u8; 64] =
-	b"TestCapsuleFormat.3A0351A7-FE90-4383-9E68-FCC20033D5F1\0\0\0\0\0\0\0\0\0\0";
+static FORMAT_UID: &'static [u8] =
+	b"TestCapsuleFormat.3A0351A7-FE90-4383-9E68-FCC20033D5F1\0";
 
 
 /// This function initializes the library, sets the log_level and returns the API version
@@ -16,8 +17,8 @@ pub extern "C" fn init(_log_level: u8) -> u8 {
 
 /// This function returns a const pointer the plugin’s capsule format UID
 #[no_mangle]
-pub extern "C" fn capsule_format_uid() -> *const u8 {
-	FORMAT_UID.as_ptr()
+pub extern "C" fn capsule_format_uid() -> *const c_char {
+	FORMAT_UID.as_ptr() as *const c_char
 }
 
 
